enable_failpoints

Macro enable_failpoints 

macro_rules! enable_failpoints {
    (true) => { ... };
    (false) => { ... };
}
Enable or disable failpoints

This is primarily indented to be used in the test code which is run under Runner::run(). For instance, you may want to run the tested code twice, first time with failpoints enabled to simulate all possible failures, then with failpoints disabled to simulate eventual successful execution and check how it recovers from previous errors.

It can be run from the instrumented code as well, though.

Like inject_* macros, it does nothing outside of Runner::run().